==> allegro-devel-5.0.9_2.txz: usr/local/share/examples/allegro-devel/demos/speed/CMakeFiles/speed.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/a4_aux.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/a4_aux.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/badguys.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/badguys.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/bullets.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/bullets.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/explode.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/explode.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/hiscore.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/hiscore.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/main.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/main.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/message.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/message.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/player.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/player.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/sound.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/sound.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/title.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/title.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/view.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/view.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/main/CMakeFiles/allegro_main.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/audio/CMakeFiles/allegro_audio.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/primitives/CMakeFiles/allegro_primitives.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/font/CMakeFiles/allegro_font.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/image/CMakeFiles/allegro_image.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/CMakeFiles/allegro.dir/DependInfo.cmake"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "include"
  "addons/main"
  "addons/audio"
  "addons/font"
  "addons/primitives"
  )
set(CMAKE_CXX_TARGET_INCLUDE_PATH ${CMAKE_C_TARGET_INCLUDE_PATH})
set(CMAKE_Fortran_TARGET_INCLUDE_PATH ${CMAKE_C_TARGET_INCLUDE_PATH})
set(CMAKE_ASM_TARGET_INCLUDE_PATH ${CMAKE_C_TARGET_INCLUDE_PATH})

==> allegro-devel-5.0.9_4.txz: usr/local/share/examples/allegro-devel/demos/speed/CMakeFiles/speed.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/a4_aux.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/a4_aux.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/badguys.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/badguys.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/bullets.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/bullets.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/explode.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/explode.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/hiscore.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/hiscore.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/main.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/main.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/message.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/message.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/player.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/player.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/sound.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/sound.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/title.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/title.c.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/view.c" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/demos/speed/CMakeFiles/speed.dir/view.c.o"
  )
set(CMAKE_C_COMPILER_ID "Clang")

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "include"
  "addons/main"
  "addons/audio"
  "addons/font"
  "addons/primitives"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/main/CMakeFiles/allegro_main.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/audio/CMakeFiles/allegro_audio.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/primitives/CMakeFiles/allegro_primitives.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/font/CMakeFiles/allegro_font.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/image/CMakeFiles/allegro_image.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/CMakeFiles/allegro.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
